#!/bin/bash

# Automates the packaging process of the software "tcl_tk-docs" for
# use with Zenwalk Linux.
#	
# Copyright (C) 2008 Michael Verret <michael.verret@gmail.com>

# Summary:	Dynamic programming language, suitable for a wide range of uses.
# License:	This software is copyrighted by the Regents of the
# 			University of California, Sun Microsystems, Inc., Scriptics
#			Corporation, ActiveState Corporation and other parties.
# Group:	extra/d
# URL:		http://www.tcl.tk/
# Build dependencies:
# Runtime dependencies:


# Variables:
#_______________________________________________________________________



Build_Root=$(pwd)

Software_Name="tcl_tk-docs"
Software_Version="8.5.4"
Package_Build="54.1"

Flag_Arch='noarch'

Standard_Docs="AUTHORS BUGS COPYING ChangeLog INSTALL LICENSE NEWS README"

Installation_Root="${Build_Root}/${Software_Name}-${Software_Version}-${Flag_Arch}-${Package_Build}"

Source_00_Title="tcl_tk-docs-8.5.4"

Source_00_URL="http://voxel.dl.sourceforge.net/sourceforge/tcl/tcl8.5.4-html.tar.gz"

Patch_00="tcl_tk-docs.png"

Script_00="build-${Software_Name}.sh"

Binary_Pkg_String="${Software_Name}-${Software_Version}-${Flag_Arch}-${Package_Build}"
Source_Pkg_String="${Software_Name}-${Software_Version}-${Flag_Arch}-${Package_Build}-src"

Binary_Install_Root="${Build_Root}/${Binary_Pkg_String}"
Source_Install_Root="${Build_Root}/${Source_Pkg_String}"



# Clean & Prep:
#_______________________________________________________________________



# Pre Build Cleanup
	cd ${Build_Root}
	Old_Files=" \
		${Installation_Root} \
		${Binary_Pkg_String}* \
		${Source_Pkg_String}*"
	for Unneeded in ${Old_Files} ; do
		if [ -e ${Unneeded} ] ; then
			rm -rf ${Unneeded}
		fi
	done
# Create Installation_Root
	mkdir ${Installation_Root}
# Add a package description file:
mkdir -p ${Installation_Root}/install
cat <<EOF0 > ${Installation_Root}/install/slack-desc 
           |-----handy-ruler------------------------------------------------------|
tcl_tk-docs: tcl_tk-docs (Advanced documentation for TCL & TK)
tcl_tk-docs: 
tcl_tk-docs: This package contains advanced documentation for the TCL
tcl_tk-docs: programming language and the Tk widget toolkit.
tcl_tk-docs: 
tcl_tk-docs: Topics covered include the interpreters which implement Tcl
tcl_tk-docs: and Tk, the commands which the tclsh interpreter implements,
tcl_tk-docs: the additional commands which the wish interpreter implements,
tcl_tk-docs: the C functions which a Tcl extended C program may use, the
tcl_tk-docs: additional C functions which a Tk extended C program may use,
tcl_tk-docs: the keywords from the Tcl/Tk man pages.
EOF0
# Install build scripts and patches:
	mkdir -p ${Installation_Root}/usr/src/${Software_Name}-${Software_Version}
	cp \
		build-${Software_Name}.sh \
		${Patch_00} \
		${Installation_Root}/usr/src/${Software_Name}-${Software_Version}/



# Build tcl_tk-docs
#_______________________________________________________________________



# Clean:
	cd ${Build_Root}
	rm -rf ${Source_00_Title}
# Extract:
	tar -xzf tcl${Software_Version}-html.tar.gz
	mv tcl${Software_Version} ${Source_00_Title}
# Enter:
	cd ${Source_00_Title}/
# Ensure proper permissions and ownership:
	chown -R root:root .
	find . -perm 666 -exec chmod 644 {} \;  
	find . -perm 664 -exec chmod 644 {} \;
	find . -perm 600 -exec chmod 644 {} \;
	find . -perm 444 -exec chmod 644 {} \;
	find . -perm 400 -exec chmod 644 {} \;
	find . -perm 440 -exec chmod 644 {} \;
	find . -perm 777 -exec chmod 755 {} \;
	find . -perm 775 -exec chmod 755 {} \;
	find . -perm 511 -exec chmod 755 {} \;
	find . -perm 711 -exec chmod 755 {} \;
	find . -perm 555 -exec chmod 755 {} \;
# Install documentation:
	mkdir -p ${Installation_Root}/usr/doc/${Software_Name}-${Software_Version}/
	cp -aR * ${Installation_Root}/usr/doc/${Software_Name}-${Software_Version}/
# Add Useful Symlinks:
	mkdir -p ${Installation_Root}/usr/doc/tcl-${Software_Version}
	(
		cd ${Installation_Root}/usr/doc/tcl-${Software_Version} ; \
			ln -sf /usr/doc/tcl_tk-docs-${Software_Version}/html/ html
	)
	mkdir -p ${Installation_Root}/usr/doc/tk-${Software_Version}
	(
		cd ${Installation_Root}/usr/doc/tk-${Software_Version} ; \
		ln -sf /usr/doc/tcl_tk-docs-${Software_Version}/html/ html
	)
# Add tcl/tk guide Launcher:
	mkdir -p ${Installation_Root}/usr/share/applications
cat <<EOF1 > ${Installation_Root}/usr/share/applications/tcl_tk-docs.desktop
[Desktop Entry]
Encoding=UTF-8
Exec=firefox file:///usr/doc/tcl_tk-docs-8.5.4/html/contents.htm
Icon=tcl_tk-docs
Type=Application
Categories=Application;Development;
Name=Tcl8.5.4/Tk8.5.4 Documentation
GenericName=Advanced Tcl8.5.4/Tk8.5.4 Documentation
EOF1

mkdir -p ${Installation_Root}/usr/share/icons/hicolor/48x48/apps
cp ${Build_Root}/tcl_tk-docs.png ${Installation_Root}/usr/share/icons/hicolor/48x48/apps/
# Clean:
	cd ${Build_Root}
	rm -rf ${Source_00_Title}



# Packaging:
#_______________________________________________________________________



# Strip Binaries:
	(
		cd ${Installation_Root}
		find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
		find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
	)
# Compress the man pages.
	if [ -d ${Installation_Root}/usr/man ]; then
	(
		cd ${Installation_Root}/usr/man
		for Man_Page_Directory in $(find . -type d -name "man*") ; do
			(
				cd ${Man_Page_Directory}
				gzip -9 *.?
			)
		done
	)
	fi
# Create dep file:
	(
		cd ${Installation_Root}
		requiredbuilder -z ${Installation_Root} >> ${Build_Root}/${Binary_Pkg_String}.dep
	)
# Compress The Package:
    (
      cd ${Installation_Root}
      makepkg -l y -c n ${Build_Root}/${Binary_Pkg_String}.tgz
    )
# Calculate The MD5 Sum:
    cd ${Build_Root}
      md5sum ${Binary_Pkg_String}.tgz > ${Binary_Pkg_String}.md5
      rm -rf ${Installation_Root}
# Create a source package and checksum:
	cd ${Build_Root}
	mkdir ${Binary_Pkg_String}-src
	cp \
		tcl${Software_Version}-html.tar.gz \
		${Script_00} \
		${Patch_00} \
		${Binary_Pkg_String}-src
	tar -cf ${Binary_Pkg_String}-src.tar ${Binary_Pkg_String}-src
	bzip2 --best ${Binary_Pkg_String}-src.tar 
	md5sum ${Binary_Pkg_String}-src.tar.bz2 > ${Binary_Pkg_String}-src.md5
	rm -rf ${Binary_Pkg_String}-src
# Post Build Cleanup
	cd ${Build_Root}
	Old_Directories=" \
		${Installation_Root}"
	for Unneeded in ${Old_Directories} ; do
		if [ -e ${Unneeded} ] ; then
			rm -rf ${Unneeded}
		fi
	done



# Changelog:
#_______________________________________________________________________



# ~ Thu Sep 11 2008	Michael Verret "axxium"<michael.verret@gmail.com>
# ~ Updated tcl_tk-docs 8.5.4
